package org.docx4j.dml.chart;

import java.util.List;

/**
 * Set/Get the content for Bubble and scatter graphic  */

public interface ISerContentXY extends ISerErrorBarListContent {

    public List<CTDPt> getDPt();

    public CTDLbls getDLbls();
    public void setDLbls(CTDLbls parValue);

    public List<CTTrendline> getTrendline();

}
